Minor fixes for recent Smalltalk/X
authorJan Vrany <jan.vrany@fit.cvut.cz>
Fri, 26 Dec 2014 23:53:37 +0100
changeset 33 f87d54770abe
parent 32 d7464405cbda
child 34 834ca32d06b2
Minor fixes for recent Smalltalk/X
Cface__CDefinitionParser.st
Cface__TypeResolver.st
Make.proto
Make.spec
Makefile.init
abbrev.stc
bc.mak
bmake.bat
cface.rc
extensions.st
jv_cface.st
lccmake.bat
libInit.cc
mingwmake.bat
vcmake.bat
--- a/Cface__CDefinitionParser.st	Tue Sep 23 16:52:40 2014 +0100
+++ b/Cface__CDefinitionParser.st	Fri Dec 26 23:53:37 2014 +0100
@@ -480,7 +480,9 @@
         cName:((nodes at:3) ifNotNil:[ (nodes at:3) value ]);
         values:(nodes at:4);
         foreign:false;
-        typedef:false
+        typeDef:false
+
+    "Modified: / 26-12-2014 / 23:45:27 / Jan Vrany <jan.vrany@fit.cvut.cz>"
 !
 
 reduceActionForEnum2:nodes 
@@ -488,7 +490,9 @@
         cName:((nodes at:3) ifNotNil:[ (nodes at:3) value ]);
         values:(nodes at:4);
         foreign:true;
-        typedef:false
+        typeDef:false
+
+    "Modified: / 26-12-2014 / 23:45:37 / Jan Vrany <jan.vrany@fit.cvut.cz>"
 !
 
 reduceActionForEnumField1:nodes 
@@ -1518,3 +1522,4 @@
 version_SVN
     ^ '$Id$'
 ! !
+
--- a/Cface__TypeResolver.st	Tue Sep 23 16:52:40 2014 +0100
+++ b/Cface__TypeResolver.st	Fri Dec 26 23:53:37 2014 +0100
@@ -85,6 +85,12 @@
     ^ '$Id$'
 !
 
+version_HG
+
+    ^ '$Changeset: <not expanded> $'
+!
+
 version_SVN
     ^ '$Id$'
 ! !
+
--- a/Make.spec	Tue Sep 23 16:52:40 2014 +0100
+++ b/Make.spec	Fri Dec 26 23:53:37 2014 +0100
@@ -42,6 +42,7 @@
 #  -warnNonStandard : no warnings about ST/X extensions
 #  -warnEOLComments : no warnings about EOL comment extension
 #  -warnPrivacy     : no warnings about privateClass extension
+#  -warnUnused      : no warnings about unused variables
 #
 # ********** OPTIONAL: MODIFY the next line(s) ***
 # STCWARNINGS=-warn
@@ -64,6 +65,7 @@
 	Cface::CairoMapping \
 	Cface::GTKMapping \
 	Cface::Generator \
+	Cface::Libgit2Mapping \
 	Cface::SVNMapping \
 	Cface::SmalltalkX \
 	Cface::TypeCollector \
@@ -97,61 +99,60 @@
 	Cface::CWCharNode \
 	Cface::CStructNode \
 	Cface::CUnionNode \
-	Cface::Libgit2Mapping \
 
 
 
 
 COMMON_OBJS= \
-    $(OUTDIR)Cface__CDefinitionParser.$(O) \
-    $(OUTDIR)Cface__CDefinitionScanner.$(O) \
-    $(OUTDIR)Cface__CNode.$(O) \
-    $(OUTDIR)Cface__CNodeVisitor.$(O) \
-    $(OUTDIR)Cface__GeneratorCommand.$(O) \
-    $(OUTDIR)Cface__Platform.$(O) \
-    $(OUTDIR)Cface__TypeMapping.$(O) \
-    $(OUTDIR)jv_cface.$(O) \
-    $(OUTDIR)Cface__CDefinitionNode.$(O) \
-    $(OUTDIR)Cface__CModifierNode.$(O) \
-    $(OUTDIR)Cface__CNoNode.$(O) \
-    $(OUTDIR)Cface__CairoMapping.$(O) \
-    $(OUTDIR)Cface__GTKMapping.$(O) \
-    $(OUTDIR)Cface__Generator.$(O) \
-    $(OUTDIR)Cface__SVNMapping.$(O) \
-    $(OUTDIR)Cface__SmalltalkX.$(O) \
-    $(OUTDIR)Cface__TypeCollector.$(O) \
-    $(OUTDIR)Cface__TypeMapper.$(O) \
-    $(OUTDIR)Cface__TypeResolver.$(O) \
-    $(OUTDIR)Cface__CArgumentNode.$(O) \
-    $(OUTDIR)Cface__CConstNode.$(O) \
-    $(OUTDIR)Cface__CDefinitionFileNode.$(O) \
-    $(OUTDIR)Cface__CEnumValueNode.$(O) \
-    $(OUTDIR)Cface__CFunctionNode.$(O) \
-    $(OUTDIR)Cface__CLongNode.$(O) \
-    $(OUTDIR)Cface__CShortNode.$(O) \
-    $(OUTDIR)Cface__CStructFieldNode.$(O) \
-    $(OUTDIR)Cface__CTypeNode.$(O) \
-    $(OUTDIR)Cface__CUnsignedNode.$(O) \
-    $(OUTDIR)Cface__SmalltalkXGenerator.$(O) \
-    $(OUTDIR)Cface__CArrayNode.$(O) \
-    $(OUTDIR)Cface__CBuiltinNode.$(O) \
-    $(OUTDIR)Cface__CDerivedTypeNode.$(O) \
-    $(OUTDIR)Cface__CPointerNode.$(O) \
-    $(OUTDIR)Cface__CTypedefNode.$(O) \
-    $(OUTDIR)Cface__CUserDefinedTypeNode.$(O) \
-    $(OUTDIR)Cface__CCharNode.$(O) \
-    $(OUTDIR)Cface__CDoubleNode.$(O) \
-    $(OUTDIR)Cface__CEnumNode.$(O) \
-    $(OUTDIR)Cface__CFloatNode.$(O) \
-    $(OUTDIR)Cface__CFunctionTypeNode.$(O) \
-    $(OUTDIR)Cface__CIntNode.$(O) \
-    $(OUTDIR)Cface__CStructuredNode.$(O) \
-    $(OUTDIR)Cface__CVoidNode.$(O) \
-    $(OUTDIR)Cface__CWCharNode.$(O) \
-    $(OUTDIR)Cface__CStructNode.$(O) \
-    $(OUTDIR)Cface__CUnionNode.$(O) \
-    $(OUTDIR)Cface__Libgit2Mapping.$(O) \
-    $(OUTDIR)extensions.$(O) \
+    $(OUTDIR_SLASH)Cface__CDefinitionParser.$(O) \
+    $(OUTDIR_SLASH)Cface__CDefinitionScanner.$(O) \
+    $(OUTDIR_SLASH)Cface__CNode.$(O) \
+    $(OUTDIR_SLASH)Cface__CNodeVisitor.$(O) \
+    $(OUTDIR_SLASH)Cface__GeneratorCommand.$(O) \
+    $(OUTDIR_SLASH)Cface__Platform.$(O) \
+    $(OUTDIR_SLASH)Cface__TypeMapping.$(O) \
+    $(OUTDIR_SLASH)jv_cface.$(O) \
+    $(OUTDIR_SLASH)Cface__CDefinitionNode.$(O) \
+    $(OUTDIR_SLASH)Cface__CModifierNode.$(O) \
+    $(OUTDIR_SLASH)Cface__CNoNode.$(O) \
+    $(OUTDIR_SLASH)Cface__CairoMapping.$(O) \
+    $(OUTDIR_SLASH)Cface__GTKMapping.$(O) \
+    $(OUTDIR_SLASH)Cface__Generator.$(O) \
+    $(OUTDIR_SLASH)Cface__Libgit2Mapping.$(O) \
+    $(OUTDIR_SLASH)Cface__SVNMapping.$(O) \
+    $(OUTDIR_SLASH)Cface__SmalltalkX.$(O) \
+    $(OUTDIR_SLASH)Cface__TypeCollector.$(O) \
+    $(OUTDIR_SLASH)Cface__TypeMapper.$(O) \
+    $(OUTDIR_SLASH)Cface__TypeResolver.$(O) \
+    $(OUTDIR_SLASH)Cface__CArgumentNode.$(O) \
+    $(OUTDIR_SLASH)Cface__CConstNode.$(O) \
+    $(OUTDIR_SLASH)Cface__CDefinitionFileNode.$(O) \
+    $(OUTDIR_SLASH)Cface__CEnumValueNode.$(O) \
+    $(OUTDIR_SLASH)Cface__CFunctionNode.$(O) \
+    $(OUTDIR_SLASH)Cface__CLongNode.$(O) \
+    $(OUTDIR_SLASH)Cface__CShortNode.$(O) \
+    $(OUTDIR_SLASH)Cface__CStructFieldNode.$(O) \
+    $(OUTDIR_SLASH)Cface__CTypeNode.$(O) \
+    $(OUTDIR_SLASH)Cface__CUnsignedNode.$(O) \
+    $(OUTDIR_SLASH)Cface__SmalltalkXGenerator.$(O) \
+    $(OUTDIR_SLASH)Cface__CArrayNode.$(O) \
+    $(OUTDIR_SLASH)Cface__CBuiltinNode.$(O) \
+    $(OUTDIR_SLASH)Cface__CDerivedTypeNode.$(O) \
+    $(OUTDIR_SLASH)Cface__CPointerNode.$(O) \
+    $(OUTDIR_SLASH)Cface__CTypedefNode.$(O) \
+    $(OUTDIR_SLASH)Cface__CUserDefinedTypeNode.$(O) \
+    $(OUTDIR_SLASH)Cface__CCharNode.$(O) \
+    $(OUTDIR_SLASH)Cface__CDoubleNode.$(O) \
+    $(OUTDIR_SLASH)Cface__CEnumNode.$(O) \
+    $(OUTDIR_SLASH)Cface__CFloatNode.$(O) \
+    $(OUTDIR_SLASH)Cface__CFunctionTypeNode.$(O) \
+    $(OUTDIR_SLASH)Cface__CIntNode.$(O) \
+    $(OUTDIR_SLASH)Cface__CStructuredNode.$(O) \
+    $(OUTDIR_SLASH)Cface__CVoidNode.$(O) \
+    $(OUTDIR_SLASH)Cface__CWCharNode.$(O) \
+    $(OUTDIR_SLASH)Cface__CStructNode.$(O) \
+    $(OUTDIR_SLASH)Cface__CUnionNode.$(O) \
+    $(OUTDIR_SLASH)extensions.$(O) \
 
 
 
--- /dev/null	Thu Jan 01 00:00:00 1970 +0000
+++ b/Makefile.init	Fri Dec 26 23:53:37 2014 +0100
@@ -0,0 +1,27 @@
+#
+# DO NOT EDIT
+#
+# make uses this file (Makefile) only, if there is no
+# file named "makefile" (lower-case m) in the same directory.
+# My only task is to generate the real makefile and call make again.
+# Thereafter, I am no longer used and needed.
+#
+# MACOSX caveat:
+#   as filenames are not case sensitive (in a default setup),
+#   we cannot use the above trick. Therefore, this file is now named
+#   "Makefile.init", and you have to execute "make -f Makefile.init" to
+#   get the initial makefile.  This is now also done by the toplevel CONFIG
+#   script.
+
+.PHONY: run
+
+run: makefile
+	$(MAKE) -f makefile
+
+#only needed for the definition of $(TOP)
+include Make.proto
+
+makefile: mf
+
+mf:
+	$(TOP)/rules/stmkmf
--- a/abbrev.stc	Tue Sep 23 16:52:40 2014 +0100
+++ b/abbrev.stc	Fri Dec 26 23:53:37 2014 +0100
@@ -8,7 +8,7 @@
 Cface::GeneratorCommand Cface__GeneratorCommand jv:cface 'Cface-Generators' 0
 Cface::Platform Cface__Platform jv:cface 'Cface-Platforms' 0
 Cface::TypeMapping Cface__TypeMapping jv:cface 'Cface-Mappings' 0
-cvut_fel_cface cvut_fel_cface jv:cface '* Projects & Packages *' 3
+jv_cface jv_cface jv:cface '* Projects & Packages *' 3
 Cface::CDefinitionNode Cface__CDefinitionNode jv:cface 'Cface-C AST' 0
 Cface::CModifierNode Cface__CModifierNode jv:cface 'Cface-C AST' 0
 Cface::CNoNode Cface__CNoNode jv:cface 'Cface-C AST' 0
--- a/bc.mak	Tue Sep 23 16:52:40 2014 +0100
+++ b/bc.mak	Fri Dec 26 23:53:37 2014 +0100
@@ -15,7 +15,7 @@
 #    bmake clobber - clean all
 #
 # Historic Note:
-#  this used to contain only rules to make with borland 
+#  this used to contain only rules to make with borland
 #    (called via bmake, by "make.exe -f bc.mak")
 #  this has changed; it is now also possible to build using microsoft visual c
 #    (called via vcmake, by "make.exe -f bc.mak -DUSEVC")
@@ -30,7 +30,8 @@
 !INCLUDE Make.spec
 
 LIBNAME=libjv_cface
-RESFILES=cface.res
+MODULE_PATH=cface
+RESFILES=cface.$(RES)
 
 
 
@@ -48,32 +49,29 @@
 
 !INCLUDE $(TOP)\rules\stdRules_bc
 
-# build all prerequisite packages for this package
+# build all mandatory prerequisite packages (containing superclasses) for this package
 prereq:
-	pushd ..\..\..\stx\libbasic & $(MAKE_BAT) "CFLAGS_LOCAL=$(GLOBALDEFINES) "
-	pushd ..\..\..\stx\goodies\refactoryBrowser\helpers & $(MAKE_BAT) "CFLAGS_LOCAL=$(GLOBALDEFINES) "
-	pushd ..\..\..\stx\goodies\refactoryBrowser\parser & $(MAKE_BAT) "CFLAGS_LOCAL=$(GLOBALDEFINES) "
-	pushd ..\..\..\stx\libbasic2 & $(MAKE_BAT) "CFLAGS_LOCAL=$(GLOBALDEFINES) "
-	pushd ..\..\..\stx\libcomp & $(MAKE_BAT) "CFLAGS_LOCAL=$(GLOBALDEFINES) "
-	pushd ..\..\..\stx\libview & $(MAKE_BAT) "CFLAGS_LOCAL=$(GLOBALDEFINES) "
-	pushd ..\..\..\stx\libdb & $(MAKE_BAT) "CFLAGS_LOCAL=$(GLOBALDEFINES) "
-	pushd ..\..\..\stx\libview2 & $(MAKE_BAT) "CFLAGS_LOCAL=$(GLOBALDEFINES) "
-	pushd ..\..\..\stx\libdb\libodbc & $(MAKE_BAT) "CFLAGS_LOCAL=$(GLOBALDEFINES) "
-	pushd ..\..\..\stx\libdb\libsqlite & $(MAKE_BAT) "CFLAGS_LOCAL=$(GLOBALDEFINES) "
-	pushd ..\..\..\stx\goodies\sunit & $(MAKE_BAT) "CFLAGS_LOCAL=$(GLOBALDEFINES) "
-	pushd ..\..\..\stx\libui & $(MAKE_BAT) "CFLAGS_LOCAL=$(GLOBALDEFINES) "
-	pushd ..\..\..\stx\libbasic3 & $(MAKE_BAT) "CFLAGS_LOCAL=$(GLOBALDEFINES) "
-	pushd ..\..\..\stx\libwidg & $(MAKE_BAT) "CFLAGS_LOCAL=$(GLOBALDEFINES) "
-	pushd ..\..\..\stx\goodies\refactoryBrowser\changes & $(MAKE_BAT) "CFLAGS_LOCAL=$(GLOBALDEFINES) "
-	pushd ..\..\..\stx\libhtml & $(MAKE_BAT) "CFLAGS_LOCAL=$(GLOBALDEFINES) "
-	pushd ..\..\..\stx\libwidg2 & $(MAKE_BAT) "CFLAGS_LOCAL=$(GLOBALDEFINES) "
-	pushd ..\..\..\stx\goodies\smaCC & $(MAKE_BAT) "CFLAGS_LOCAL=$(GLOBALDEFINES) "
-	pushd ..\..\..\stx\librun & $(MAKE_BAT) "CFLAGS_LOCAL=$(GLOBALDEFINES) "
+	pushd ..\..\stx\libbasic & $(MAKE_BAT) "CFLAGS_LOCAL=$(GLOBALDEFINES) "
+	pushd ..\..\stx\libbasic2 & $(MAKE_BAT) "CFLAGS_LOCAL=$(GLOBALDEFINES) "
+	pushd ..\..\stx\libbasic3 & $(MAKE_BAT) "CFLAGS_LOCAL=$(GLOBALDEFINES) "
+	pushd ..\..\stx\libview & $(MAKE_BAT) "CFLAGS_LOCAL=$(GLOBALDEFINES) "
+	pushd ..\..\stx\libview2 & $(MAKE_BAT) "CFLAGS_LOCAL=$(GLOBALDEFINES) "
+	pushd ..\..\stx\goodies\smaCC & $(MAKE_BAT) "CFLAGS_LOCAL=$(GLOBALDEFINES) "
 
 
 
 
 
+
+
+test: $(TOP)\goodies\builder\reports\NUL
+	pushd $(TOP)\goodies\builder\reports & $(MAKE_BAT)
+	$(TOP)\goodies\builder\reports\report-runner.bat -D . -r Builder::TestReport -p $(PACKAGE)
+        
+clean::
+	del *.$(CSUFFIX)
+
+
 # BEGINMAKEDEPEND --- do not remove this line; make depend needs it
 $(OUTDIR)Cface__CDefinitionParser.$(O) Cface__CDefinitionParser.$(H): Cface__CDefinitionParser.st $(INCLUDE_TOP)\stx\goodies\smaCC\SmaCC__SmaCCParser.$(H) $(INCLUDE_TOP)\stx\libbasic\Object.$(H) $(STCHDR)
 $(OUTDIR)Cface__CDefinitionScanner.$(O) Cface__CDefinitionScanner.$(H): Cface__CDefinitionScanner.st $(INCLUDE_TOP)\stx\goodies\smaCC\SmaCC__SmaCCScanner.$(H) $(INCLUDE_TOP)\stx\libbasic\Object.$(H) $(STCHDR)
@@ -82,47 +80,56 @@
 $(OUTDIR)Cface__GeneratorCommand.$(O) Cface__GeneratorCommand.$(H): Cface__GeneratorCommand.st $(INCLUDE_TOP)\stx\libbasic\Object.$(H) $(STCHDR)
 $(OUTDIR)Cface__Platform.$(O) Cface__Platform.$(H): Cface__Platform.st $(INCLUDE_TOP)\stx\libbasic\Object.$(H) $(STCHDR)
 $(OUTDIR)Cface__TypeMapping.$(O) Cface__TypeMapping.$(H): Cface__TypeMapping.st $(INCLUDE_TOP)\stx\libbasic\Object.$(H) $(STCHDR)
-$(OUTDIR)jv_cface.$(O) jv_cface.$(H): jv_cface.st $(INCLUDE_TOP)\stx\libbasic\LibraryDefinition.$(H) $(INCLUDE_TOP)\stx\libbasic\ProjectDefinition.$(H) $(INCLUDE_TOP)\stx\libbasic\Object.$(H) $(STCHDR)
-$(OUTDIR)Cface__CDefinitionNode.$(O) Cface__CDefinitionNode.$(H): Cface__CDefinitionNode.st $(INCLUDE_TOP)\cvut\fel\cface\Cface__CNode.$(H) $(INCLUDE_TOP)\stx\libbasic\Object.$(H) $(STCHDR)
-$(OUTDIR)Cface__CModifierNode.$(O) Cface__CModifierNode.$(H): Cface__CModifierNode.st $(INCLUDE_TOP)\cvut\fel\cface\Cface__CNode.$(H) $(INCLUDE_TOP)\stx\libbasic\Object.$(H) $(STCHDR)
-$(OUTDIR)Cface__CNoNode.$(O) Cface__CNoNode.$(H): Cface__CNoNode.st $(INCLUDE_TOP)\cvut\fel\cface\Cface__CNode.$(H) $(INCLUDE_TOP)\stx\libbasic\Object.$(H) $(STCHDR)
-$(OUTDIR)Cface__CairoMapping.$(O) Cface__CairoMapping.$(H): Cface__CairoMapping.st $(INCLUDE_TOP)\cvut\fel\cface\Cface__TypeMapping.$(H) $(INCLUDE_TOP)\stx\libbasic\Object.$(H) $(STCHDR)
-$(OUTDIR)Cface__GTKMapping.$(O) Cface__GTKMapping.$(H): Cface__GTKMapping.st $(INCLUDE_TOP)\cvut\fel\cface\Cface__TypeMapping.$(H) $(INCLUDE_TOP)\stx\libbasic\Object.$(H) $(STCHDR)
-$(OUTDIR)Cface__Generator.$(O) Cface__Generator.$(H): Cface__Generator.st $(INCLUDE_TOP)\cvut\fel\cface\Cface__CNodeVisitor.$(H) $(INCLUDE_TOP)\stx\libbasic\Object.$(H) $(STCHDR)
-$(OUTDIR)Cface__Libgit2Mapping.$(O) Cface__Libgit2Mapping.$(H): Cface__Libgit2Mapping.st $(INCLUDE_TOP)\cvut\fel\cface\Cface__TypeMapping.$(H) $(INCLUDE_TOP)\stx\libbasic\Object.$(H) $(STCHDR)
-$(OUTDIR)Cface__SVNMapping.$(O) Cface__SVNMapping.$(H): Cface__SVNMapping.st $(INCLUDE_TOP)\cvut\fel\cface\Cface__TypeMapping.$(H) $(INCLUDE_TOP)\stx\libbasic\Object.$(H) $(STCHDR)
-$(OUTDIR)Cface__SmalltalkX.$(O) Cface__SmalltalkX.$(H): Cface__SmalltalkX.st $(INCLUDE_TOP)\cvut\fel\cface\Cface__Platform.$(H) $(INCLUDE_TOP)\stx\libbasic\Object.$(H) $(STCHDR)
-$(OUTDIR)Cface__TypeCollector.$(O) Cface__TypeCollector.$(H): Cface__TypeCollector.st $(INCLUDE_TOP)\cvut\fel\cface\Cface__CNodeVisitor.$(H) $(INCLUDE_TOP)\stx\libbasic\Object.$(H) $(STCHDR)
-$(OUTDIR)Cface__TypeMapper.$(O) Cface__TypeMapper.$(H): Cface__TypeMapper.st $(INCLUDE_TOP)\cvut\fel\cface\Cface__CNodeVisitor.$(H) $(INCLUDE_TOP)\stx\libbasic\Object.$(H) $(STCHDR)
-$(OUTDIR)Cface__TypeResolver.$(O) Cface__TypeResolver.$(H): Cface__TypeResolver.st $(INCLUDE_TOP)\cvut\fel\cface\Cface__CNodeVisitor.$(H) $(INCLUDE_TOP)\stx\libbasic\Object.$(H) $(STCHDR)
-$(OUTDIR)Cface__CArgumentNode.$(O) Cface__CArgumentNode.$(H): Cface__CArgumentNode.st $(INCLUDE_TOP)\cvut\fel\cface\Cface__CDefinitionNode.$(H) $(INCLUDE_TOP)\cvut\fel\cface\Cface__CNode.$(H) $(INCLUDE_TOP)\stx\libbasic\Object.$(H) $(STCHDR)
-$(OUTDIR)Cface__CConstNode.$(O) Cface__CConstNode.$(H): Cface__CConstNode.st $(INCLUDE_TOP)\cvut\fel\cface\Cface__CModifierNode.$(H) $(INCLUDE_TOP)\cvut\fel\cface\Cface__CNode.$(H) $(INCLUDE_TOP)\stx\libbasic\Object.$(H) $(STCHDR)
-$(OUTDIR)Cface__CDefinitionFileNode.$(O) Cface__CDefinitionFileNode.$(H): Cface__CDefinitionFileNode.st $(INCLUDE_TOP)\cvut\fel\cface\Cface__CDefinitionNode.$(H) $(INCLUDE_TOP)\cvut\fel\cface\Cface__CNode.$(H) $(INCLUDE_TOP)\stx\libbasic\Object.$(H) $(STCHDR)
-$(OUTDIR)Cface__CEnumValueNode.$(O) Cface__CEnumValueNode.$(H): Cface__CEnumValueNode.st $(INCLUDE_TOP)\cvut\fel\cface\Cface__CDefinitionNode.$(H) $(INCLUDE_TOP)\cvut\fel\cface\Cface__CNode.$(H) $(INCLUDE_TOP)\stx\libbasic\Object.$(H) $(STCHDR)
-$(OUTDIR)Cface__CFunctionNode.$(O) Cface__CFunctionNode.$(H): Cface__CFunctionNode.st $(INCLUDE_TOP)\cvut\fel\cface\Cface__CDefinitionNode.$(H) $(INCLUDE_TOP)\cvut\fel\cface\Cface__CNode.$(H) $(INCLUDE_TOP)\stx\libbasic\Object.$(H) $(STCHDR)
-$(OUTDIR)Cface__CLongNode.$(O) Cface__CLongNode.$(H): Cface__CLongNode.st $(INCLUDE_TOP)\cvut\fel\cface\Cface__CModifierNode.$(H) $(INCLUDE_TOP)\cvut\fel\cface\Cface__CNode.$(H) $(INCLUDE_TOP)\stx\libbasic\Object.$(H) $(STCHDR)
-$(OUTDIR)Cface__CShortNode.$(O) Cface__CShortNode.$(H): Cface__CShortNode.st $(INCLUDE_TOP)\cvut\fel\cface\Cface__CModifierNode.$(H) $(INCLUDE_TOP)\cvut\fel\cface\Cface__CNode.$(H) $(INCLUDE_TOP)\stx\libbasic\Object.$(H) $(STCHDR)
-$(OUTDIR)Cface__CStructFieldNode.$(O) Cface__CStructFieldNode.$(H): Cface__CStructFieldNode.st $(INCLUDE_TOP)\cvut\fel\cface\Cface__CDefinitionNode.$(H) $(INCLUDE_TOP)\cvut\fel\cface\Cface__CNode.$(H) $(INCLUDE_TOP)\stx\libbasic\Object.$(H) $(STCHDR)
-$(OUTDIR)Cface__CTypeNode.$(O) Cface__CTypeNode.$(H): Cface__CTypeNode.st $(INCLUDE_TOP)\cvut\fel\cface\Cface__CDefinitionNode.$(H) $(INCLUDE_TOP)\cvut\fel\cface\Cface__CNode.$(H) $(INCLUDE_TOP)\stx\libbasic\Object.$(H) $(STCHDR)
-$(OUTDIR)Cface__CUnsignedNode.$(O) Cface__CUnsignedNode.$(H): Cface__CUnsignedNode.st $(INCLUDE_TOP)\cvut\fel\cface\Cface__CModifierNode.$(H) $(INCLUDE_TOP)\cvut\fel\cface\Cface__CNode.$(H) $(INCLUDE_TOP)\stx\libbasic\Object.$(H) $(STCHDR)
-$(OUTDIR)Cface__SmalltalkXGenerator.$(O) Cface__SmalltalkXGenerator.$(H): Cface__SmalltalkXGenerator.st $(INCLUDE_TOP)\cvut\fel\cface\Cface__Generator.$(H) $(INCLUDE_TOP)\cvut\fel\cface\Cface__CNodeVisitor.$(H) $(INCLUDE_TOP)\stx\libbasic\Object.$(H) $(STCHDR)
-$(OUTDIR)Cface__CArrayNode.$(O) Cface__CArrayNode.$(H): Cface__CArrayNode.st $(INCLUDE_TOP)\cvut\fel\cface\Cface__CTypeNode.$(H) $(INCLUDE_TOP)\cvut\fel\cface\Cface__CDefinitionNode.$(H) $(INCLUDE_TOP)\cvut\fel\cface\Cface__CNode.$(H) $(INCLUDE_TOP)\stx\libbasic\Object.$(H) $(STCHDR)
-$(OUTDIR)Cface__CBuiltinNode.$(O) Cface__CBuiltinNode.$(H): Cface__CBuiltinNode.st $(INCLUDE_TOP)\cvut\fel\cface\Cface__CTypeNode.$(H) $(INCLUDE_TOP)\cvut\fel\cface\Cface__CDefinitionNode.$(H) $(INCLUDE_TOP)\cvut\fel\cface\Cface__CNode.$(H) $(INCLUDE_TOP)\stx\libbasic\Object.$(H) $(STCHDR)
-$(OUTDIR)Cface__CDerivedTypeNode.$(O) Cface__CDerivedTypeNode.$(H): Cface__CDerivedTypeNode.st $(INCLUDE_TOP)\cvut\fel\cface\Cface__CTypeNode.$(H) $(INCLUDE_TOP)\cvut\fel\cface\Cface__CDefinitionNode.$(H) $(INCLUDE_TOP)\cvut\fel\cface\Cface__CNode.$(H) $(INCLUDE_TOP)\stx\libbasic\Object.$(H) $(STCHDR)
-$(OUTDIR)Cface__CPointerNode.$(O) Cface__CPointerNode.$(H): Cface__CPointerNode.st $(INCLUDE_TOP)\cvut\fel\cface\Cface__CTypeNode.$(H) $(INCLUDE_TOP)\cvut\fel\cface\Cface__CDefinitionNode.$(H) $(INCLUDE_TOP)\cvut\fel\cface\Cface__CNode.$(H) $(INCLUDE_TOP)\stx\libbasic\Object.$(H) $(STCHDR)
-$(OUTDIR)Cface__CTypedefNode.$(O) Cface__CTypedefNode.$(H): Cface__CTypedefNode.st $(INCLUDE_TOP)\cvut\fel\cface\Cface__CTypeNode.$(H) $(INCLUDE_TOP)\cvut\fel\cface\Cface__CDefinitionNode.$(H) $(INCLUDE_TOP)\cvut\fel\cface\Cface__CNode.$(H) $(INCLUDE_TOP)\stx\libbasic\Object.$(H) $(STCHDR)
-$(OUTDIR)Cface__CUserDefinedTypeNode.$(O) Cface__CUserDefinedTypeNode.$(H): Cface__CUserDefinedTypeNode.st $(INCLUDE_TOP)\cvut\fel\cface\Cface__CTypeNode.$(H) $(INCLUDE_TOP)\cvut\fel\cface\Cface__CDefinitionNode.$(H) $(INCLUDE_TOP)\cvut\fel\cface\Cface__CNode.$(H) $(INCLUDE_TOP)\stx\libbasic\Object.$(H) $(STCHDR)
-$(OUTDIR)Cface__CCharNode.$(O) Cface__CCharNode.$(H): Cface__CCharNode.st $(INCLUDE_TOP)\cvut\fel\cface\Cface__CBuiltinNode.$(H) $(INCLUDE_TOP)\cvut\fel\cface\Cface__CTypeNode.$(H) $(INCLUDE_TOP)\cvut\fel\cface\Cface__CDefinitionNode.$(H) $(INCLUDE_TOP)\cvut\fel\cface\Cface__CNode.$(H) $(INCLUDE_TOP)\stx\libbasic\Object.$(H) $(STCHDR)
-$(OUTDIR)Cface__CDoubleNode.$(O) Cface__CDoubleNode.$(H): Cface__CDoubleNode.st $(INCLUDE_TOP)\cvut\fel\cface\Cface__CBuiltinNode.$(H) $(INCLUDE_TOP)\cvut\fel\cface\Cface__CTypeNode.$(H) $(INCLUDE_TOP)\cvut\fel\cface\Cface__CDefinitionNode.$(H) $(INCLUDE_TOP)\cvut\fel\cface\Cface__CNode.$(H) $(INCLUDE_TOP)\stx\libbasic\Object.$(H) $(STCHDR)
-$(OUTDIR)Cface__CEnumNode.$(O) Cface__CEnumNode.$(H): Cface__CEnumNode.st $(INCLUDE_TOP)\cvut\fel\cface\Cface__CDerivedTypeNode.$(H) $(INCLUDE_TOP)\cvut\fel\cface\Cface__CTypeNode.$(H) $(INCLUDE_TOP)\cvut\fel\cface\Cface__CDefinitionNode.$(H) $(INCLUDE_TOP)\cvut\fel\cface\Cface__CNode.$(H) $(INCLUDE_TOP)\stx\libbasic\Object.$(H) $(STCHDR)
-$(OUTDIR)Cface__CFloatNode.$(O) Cface__CFloatNode.$(H): Cface__CFloatNode.st $(INCLUDE_TOP)\cvut\fel\cface\Cface__CBuiltinNode.$(H) $(INCLUDE_TOP)\cvut\fel\cface\Cface__CTypeNode.$(H) $(INCLUDE_TOP)\cvut\fel\cface\Cface__CDefinitionNode.$(H) $(INCLUDE_TOP)\cvut\fel\cface\Cface__CNode.$(H) $(INCLUDE_TOP)\stx\libbasic\Object.$(H) $(STCHDR)
-$(OUTDIR)Cface__CFunctionTypeNode.$(O) Cface__CFunctionTypeNode.$(H): Cface__CFunctionTypeNode.st $(INCLUDE_TOP)\cvut\fel\cface\Cface__CDerivedTypeNode.$(H) $(INCLUDE_TOP)\cvut\fel\cface\Cface__CTypeNode.$(H) $(INCLUDE_TOP)\cvut\fel\cface\Cface__CDefinitionNode.$(H) $(INCLUDE_TOP)\cvut\fel\cface\Cface__CNode.$(H) $(INCLUDE_TOP)\stx\libbasic\Object.$(H) $(STCHDR)
-$(OUTDIR)Cface__CIntNode.$(O) Cface__CIntNode.$(H): Cface__CIntNode.st $(INCLUDE_TOP)\cvut\fel\cface\Cface__CBuiltinNode.$(H) $(INCLUDE_TOP)\cvut\fel\cface\Cface__CTypeNode.$(H) $(INCLUDE_TOP)\cvut\fel\cface\Cface__CDefinitionNode.$(H) $(INCLUDE_TOP)\cvut\fel\cface\Cface__CNode.$(H) $(INCLUDE_TOP)\stx\libbasic\Object.$(H) $(STCHDR)
-$(OUTDIR)Cface__CStructuredNode.$(O) Cface__CStructuredNode.$(H): Cface__CStructuredNode.st $(INCLUDE_TOP)\cvut\fel\cface\Cface__CDerivedTypeNode.$(H) $(INCLUDE_TOP)\cvut\fel\cface\Cface__CTypeNode.$(H) $(INCLUDE_TOP)\cvut\fel\cface\Cface__CDefinitionNode.$(H) $(INCLUDE_TOP)\cvut\fel\cface\Cface__CNode.$(H) $(INCLUDE_TOP)\stx\libbasic\Object.$(H) $(STCHDR)
-$(OUTDIR)Cface__CVoidNode.$(O) Cface__CVoidNode.$(H): Cface__CVoidNode.st $(INCLUDE_TOP)\cvut\fel\cface\Cface__CBuiltinNode.$(H) $(INCLUDE_TOP)\cvut\fel\cface\Cface__CTypeNode.$(H) $(INCLUDE_TOP)\cvut\fel\cface\Cface__CDefinitionNode.$(H) $(INCLUDE_TOP)\cvut\fel\cface\Cface__CNode.$(H) $(INCLUDE_TOP)\stx\libbasic\Object.$(H) $(STCHDR)
-$(OUTDIR)Cface__CWCharNode.$(O) Cface__CWCharNode.$(H): Cface__CWCharNode.st $(INCLUDE_TOP)\cvut\fel\cface\Cface__CBuiltinNode.$(H) $(INCLUDE_TOP)\cvut\fel\cface\Cface__CTypeNode.$(H) $(INCLUDE_TOP)\cvut\fel\cface\Cface__CDefinitionNode.$(H) $(INCLUDE_TOP)\cvut\fel\cface\Cface__CNode.$(H) $(INCLUDE_TOP)\stx\libbasic\Object.$(H) $(STCHDR)
-$(OUTDIR)Cface__CStructNode.$(O) Cface__CStructNode.$(H): Cface__CStructNode.st $(INCLUDE_TOP)\cvut\fel\cface\Cface__CStructuredNode.$(H) $(INCLUDE_TOP)\cvut\fel\cface\Cface__CDerivedTypeNode.$(H) $(INCLUDE_TOP)\cvut\fel\cface\Cface__CTypeNode.$(H) $(INCLUDE_TOP)\cvut\fel\cface\Cface__CDefinitionNode.$(H) $(INCLUDE_TOP)\cvut\fel\cface\Cface__CNode.$(H) $(INCLUDE_TOP)\stx\libbasic\Object.$(H) $(STCHDR)
-$(OUTDIR)Cface__CUnionNode.$(O) Cface__CUnionNode.$(H): Cface__CUnionNode.st $(INCLUDE_TOP)\cvut\fel\cface\Cface__CStructuredNode.$(H) $(INCLUDE_TOP)\cvut\fel\cface\Cface__CDerivedTypeNode.$(H) $(INCLUDE_TOP)\cvut\fel\cface\Cface__CTypeNode.$(H) $(INCLUDE_TOP)\cvut\fel\cface\Cface__CDefinitionNode.$(H) $(INCLUDE_TOP)\cvut\fel\cface\Cface__CNode.$(H) $(INCLUDE_TOP)\stx\libbasic\Object.$(H) $(STCHDR)
-$(OUTDIR)extensions.$(O): extensions.st $(INCLUDE_TOP)\stx\libbasic3\ClassDefinitionChange.$(H) $(INCLUDE_TOP)\stx\libbasic3\ClassChange.$(H) $(INCLUDE_TOP)\stx\libbasic3\Change.$(H) $(INCLUDE_TOP)\stx\libbasic\Object.$(H) $(INCLUDE_TOP)\stx\libbasic\Stream.$(H) $(STCHDR)
+$(OUTDIR)jv_cface.$(O) jv_cface.$(H): jv_cface.st $(INCLUDE_TOP)\stx\libbasic\LibraryDefinition.$(H) $(INCLUDE_TOP)\stx\libbasic\Object.$(H) $(INCLUDE_TOP)\stx\libbasic\ProjectDefinition.$(H) $(STCHDR)
+$(OUTDIR)Cface__CDefinitionNode.$(O) Cface__CDefinitionNode.$(H): Cface__CDefinitionNode.st $(INCLUDE_TOP)\jv\cface\Cface__CNode.$(H) $(INCLUDE_TOP)\stx\libbasic\Object.$(H) $(STCHDR)
+$(OUTDIR)Cface__CModifierNode.$(O) Cface__CModifierNode.$(H): Cface__CModifierNode.st $(INCLUDE_TOP)\jv\cface\Cface__CNode.$(H) $(INCLUDE_TOP)\stx\libbasic\Object.$(H) $(STCHDR)
+$(OUTDIR)Cface__CNoNode.$(O) Cface__CNoNode.$(H): Cface__CNoNode.st $(INCLUDE_TOP)\jv\cface\Cface__CNode.$(H) $(INCLUDE_TOP)\stx\libbasic\Object.$(H) $(STCHDR)
+$(OUTDIR)Cface__CairoMapping.$(O) Cface__CairoMapping.$(H): Cface__CairoMapping.st $(INCLUDE_TOP)\jv\cface\Cface__TypeMapping.$(H) $(INCLUDE_TOP)\stx\libbasic\Object.$(H) $(STCHDR)
+$(OUTDIR)Cface__GTKMapping.$(O) Cface__GTKMapping.$(H): Cface__GTKMapping.st $(INCLUDE_TOP)\jv\cface\Cface__TypeMapping.$(H) $(INCLUDE_TOP)\stx\libbasic\Object.$(H) $(STCHDR)
+$(OUTDIR)Cface__Generator.$(O) Cface__Generator.$(H): Cface__Generator.st $(INCLUDE_TOP)\jv\cface\Cface__CNodeVisitor.$(H) $(INCLUDE_TOP)\stx\libbasic\Object.$(H) $(STCHDR)
+$(OUTDIR)Cface__Libgit2Mapping.$(O) Cface__Libgit2Mapping.$(H): Cface__Libgit2Mapping.st $(INCLUDE_TOP)\jv\cface\Cface__TypeMapping.$(H) $(INCLUDE_TOP)\stx\libbasic\Object.$(H) $(STCHDR)
+$(OUTDIR)Cface__SVNMapping.$(O) Cface__SVNMapping.$(H): Cface__SVNMapping.st $(INCLUDE_TOP)\jv\cface\Cface__TypeMapping.$(H) $(INCLUDE_TOP)\stx\libbasic\Object.$(H) $(STCHDR)
+$(OUTDIR)Cface__SmalltalkX.$(O) Cface__SmalltalkX.$(H): Cface__SmalltalkX.st $(INCLUDE_TOP)\jv\cface\Cface__Platform.$(H) $(INCLUDE_TOP)\stx\libbasic\Object.$(H) $(STCHDR)
+$(OUTDIR)Cface__TypeCollector.$(O) Cface__TypeCollector.$(H): Cface__TypeCollector.st $(INCLUDE_TOP)\jv\cface\Cface__CNodeVisitor.$(H) $(INCLUDE_TOP)\stx\libbasic\Object.$(H) $(STCHDR)
+$(OUTDIR)Cface__TypeMapper.$(O) Cface__TypeMapper.$(H): Cface__TypeMapper.st $(INCLUDE_TOP)\jv\cface\Cface__CNodeVisitor.$(H) $(INCLUDE_TOP)\stx\libbasic\Object.$(H) $(STCHDR)
+$(OUTDIR)Cface__TypeResolver.$(O) Cface__TypeResolver.$(H): Cface__TypeResolver.st $(INCLUDE_TOP)\jv\cface\Cface__CNodeVisitor.$(H) $(INCLUDE_TOP)\stx\libbasic\Object.$(H) $(STCHDR)
+$(OUTDIR)Cface__CArgumentNode.$(O) Cface__CArgumentNode.$(H): Cface__CArgumentNode.st $(INCLUDE_TOP)\jv\cface\Cface__CDefinitionNode.$(H) $(INCLUDE_TOP)\jv\cface\Cface__CNode.$(H) $(INCLUDE_TOP)\stx\libbasic\Object.$(H) $(STCHDR)
+$(OUTDIR)Cface__CConstNode.$(O) Cface__CConstNode.$(H): Cface__CConstNode.st $(INCLUDE_TOP)\jv\cface\Cface__CModifierNode.$(H) $(INCLUDE_TOP)\jv\cface\Cface__CNode.$(H) $(INCLUDE_TOP)\stx\libbasic\Object.$(H) $(STCHDR)
+$(OUTDIR)Cface__CDefinitionFileNode.$(O) Cface__CDefinitionFileNode.$(H): Cface__CDefinitionFileNode.st $(INCLUDE_TOP)\jv\cface\Cface__CDefinitionNode.$(H) $(INCLUDE_TOP)\jv\cface\Cface__CNode.$(H) $(INCLUDE_TOP)\stx\libbasic\Object.$(H) $(STCHDR)
+$(OUTDIR)Cface__CEnumValueNode.$(O) Cface__CEnumValueNode.$(H): Cface__CEnumValueNode.st $(INCLUDE_TOP)\jv\cface\Cface__CDefinitionNode.$(H) $(INCLUDE_TOP)\jv\cface\Cface__CNode.$(H) $(INCLUDE_TOP)\stx\libbasic\Object.$(H) $(STCHDR)
+$(OUTDIR)Cface__CFunctionNode.$(O) Cface__CFunctionNode.$(H): Cface__CFunctionNode.st $(INCLUDE_TOP)\jv\cface\Cface__CDefinitionNode.$(H) $(INCLUDE_TOP)\jv\cface\Cface__CNode.$(H) $(INCLUDE_TOP)\stx\libbasic\Object.$(H) $(STCHDR)
+$(OUTDIR)Cface__CLongNode.$(O) Cface__CLongNode.$(H): Cface__CLongNode.st $(INCLUDE_TOP)\jv\cface\Cface__CModifierNode.$(H) $(INCLUDE_TOP)\jv\cface\Cface__CNode.$(H) $(INCLUDE_TOP)\stx\libbasic\Object.$(H) $(STCHDR)
+$(OUTDIR)Cface__CShortNode.$(O) Cface__CShortNode.$(H): Cface__CShortNode.st $(INCLUDE_TOP)\jv\cface\Cface__CModifierNode.$(H) $(INCLUDE_TOP)\jv\cface\Cface__CNode.$(H) $(INCLUDE_TOP)\stx\libbasic\Object.$(H) $(STCHDR)
+$(OUTDIR)Cface__CStructFieldNode.$(O) Cface__CStructFieldNode.$(H): Cface__CStructFieldNode.st $(INCLUDE_TOP)\jv\cface\Cface__CDefinitionNode.$(H) $(INCLUDE_TOP)\jv\cface\Cface__CNode.$(H) $(INCLUDE_TOP)\stx\libbasic\Object.$(H) $(STCHDR)
+$(OUTDIR)Cface__CTypeNode.$(O) Cface__CTypeNode.$(H): Cface__CTypeNode.st $(INCLUDE_TOP)\jv\cface\Cface__CDefinitionNode.$(H) $(INCLUDE_TOP)\jv\cface\Cface__CNode.$(H) $(INCLUDE_TOP)\stx\libbasic\Object.$(H) $(STCHDR)
+$(OUTDIR)Cface__CUnsignedNode.$(O) Cface__CUnsignedNode.$(H): Cface__CUnsignedNode.st $(INCLUDE_TOP)\jv\cface\Cface__CModifierNode.$(H) $(INCLUDE_TOP)\jv\cface\Cface__CNode.$(H) $(INCLUDE_TOP)\stx\libbasic\Object.$(H) $(STCHDR)
+$(OUTDIR)Cface__SmalltalkXGenerator.$(O) Cface__SmalltalkXGenerator.$(H): Cface__SmalltalkXGenerator.st $(INCLUDE_TOP)\jv\cface\Cface__CNodeVisitor.$(H) $(INCLUDE_TOP)\jv\cface\Cface__Generator.$(H) $(INCLUDE_TOP)\stx\libbasic\Object.$(H) $(STCHDR)
+$(OUTDIR)Cface__CArrayNode.$(O) Cface__CArrayNode.$(H): Cface__CArrayNode.st $(INCLUDE_TOP)\jv\cface\Cface__CDefinitionNode.$(H) $(INCLUDE_TOP)\jv\cface\Cface__CNode.$(H) $(INCLUDE_TOP)\jv\cface\Cface__CTypeNode.$(H) $(INCLUDE_TOP)\stx\libbasic\Object.$(H) $(STCHDR)
+$(OUTDIR)Cface__CBuiltinNode.$(O) Cface__CBuiltinNode.$(H): Cface__CBuiltinNode.st $(INCLUDE_TOP)\jv\cface\Cface__CDefinitionNode.$(H) $(INCLUDE_TOP)\jv\cface\Cface__CNode.$(H) $(INCLUDE_TOP)\jv\cface\Cface__CTypeNode.$(H) $(INCLUDE_TOP)\stx\libbasic\Object.$(H) $(STCHDR)
+$(OUTDIR)Cface__CDerivedTypeNode.$(O) Cface__CDerivedTypeNode.$(H): Cface__CDerivedTypeNode.st $(INCLUDE_TOP)\jv\cface\Cface__CDefinitionNode.$(H) $(INCLUDE_TOP)\jv\cface\Cface__CNode.$(H) $(INCLUDE_TOP)\jv\cface\Cface__CTypeNode.$(H) $(INCLUDE_TOP)\stx\libbasic\Object.$(H) $(STCHDR)
+$(OUTDIR)Cface__CPointerNode.$(O) Cface__CPointerNode.$(H): Cface__CPointerNode.st $(INCLUDE_TOP)\jv\cface\Cface__CDefinitionNode.$(H) $(INCLUDE_TOP)\jv\cface\Cface__CNode.$(H) $(INCLUDE_TOP)\jv\cface\Cface__CTypeNode.$(H) $(INCLUDE_TOP)\stx\libbasic\Object.$(H) $(STCHDR)
+$(OUTDIR)Cface__CTypedefNode.$(O) Cface__CTypedefNode.$(H): Cface__CTypedefNode.st $(INCLUDE_TOP)\jv\cface\Cface__CDefinitionNode.$(H) $(INCLUDE_TOP)\jv\cface\Cface__CNode.$(H) $(INCLUDE_TOP)\jv\cface\Cface__CTypeNode.$(H) $(INCLUDE_TOP)\stx\libbasic\Object.$(H) $(STCHDR)
+$(OUTDIR)Cface__CUserDefinedTypeNode.$(O) Cface__CUserDefinedTypeNode.$(H): Cface__CUserDefinedTypeNode.st $(INCLUDE_TOP)\jv\cface\Cface__CDefinitionNode.$(H) $(INCLUDE_TOP)\jv\cface\Cface__CNode.$(H) $(INCLUDE_TOP)\jv\cface\Cface__CTypeNode.$(H) $(INCLUDE_TOP)\stx\libbasic\Object.$(H) $(STCHDR)
+$(OUTDIR)Cface__CCharNode.$(O) Cface__CCharNode.$(H): Cface__CCharNode.st $(INCLUDE_TOP)\jv\cface\Cface__CBuiltinNode.$(H) $(INCLUDE_TOP)\jv\cface\Cface__CDefinitionNode.$(H) $(INCLUDE_TOP)\jv\cface\Cface__CNode.$(H) $(INCLUDE_TOP)\jv\cface\Cface__CTypeNode.$(H) $(INCLUDE_TOP)\stx\libbasic\Object.$(H) $(STCHDR)
+$(OUTDIR)Cface__CDoubleNode.$(O) Cface__CDoubleNode.$(H): Cface__CDoubleNode.st $(INCLUDE_TOP)\jv\cface\Cface__CBuiltinNode.$(H) $(INCLUDE_TOP)\jv\cface\Cface__CDefinitionNode.$(H) $(INCLUDE_TOP)\jv\cface\Cface__CNode.$(H) $(INCLUDE_TOP)\jv\cface\Cface__CTypeNode.$(H) $(INCLUDE_TOP)\stx\libbasic\Object.$(H) $(STCHDR)
+$(OUTDIR)Cface__CEnumNode.$(O) Cface__CEnumNode.$(H): Cface__CEnumNode.st $(INCLUDE_TOP)\jv\cface\Cface__CDefinitionNode.$(H) $(INCLUDE_TOP)\jv\cface\Cface__CDerivedTypeNode.$(H) $(INCLUDE_TOP)\jv\cface\Cface__CNode.$(H) $(INCLUDE_TOP)\jv\cface\Cface__CTypeNode.$(H) $(INCLUDE_TOP)\stx\libbasic\Object.$(H) $(STCHDR)
+$(OUTDIR)Cface__CFloatNode.$(O) Cface__CFloatNode.$(H): Cface__CFloatNode.st $(INCLUDE_TOP)\jv\cface\Cface__CBuiltinNode.$(H) $(INCLUDE_TOP)\jv\cface\Cface__CDefinitionNode.$(H) $(INCLUDE_TOP)\jv\cface\Cface__CNode.$(H) $(INCLUDE_TOP)\jv\cface\Cface__CTypeNode.$(H) $(INCLUDE_TOP)\stx\libbasic\Object.$(H) $(STCHDR)
+$(OUTDIR)Cface__CFunctionTypeNode.$(O) Cface__CFunctionTypeNode.$(H): Cface__CFunctionTypeNode.st $(INCLUDE_TOP)\jv\cface\Cface__CDefinitionNode.$(H) $(INCLUDE_TOP)\jv\cface\Cface__CDerivedTypeNode.$(H) $(INCLUDE_TOP)\jv\cface\Cface__CNode.$(H) $(INCLUDE_TOP)\jv\cface\Cface__CTypeNode.$(H) $(INCLUDE_TOP)\stx\libbasic\Object.$(H) $(STCHDR)
+$(OUTDIR)Cface__CIntNode.$(O) Cface__CIntNode.$(H): Cface__CIntNode.st $(INCLUDE_TOP)\jv\cface\Cface__CBuiltinNode.$(H) $(INCLUDE_TOP)\jv\cface\Cface__CDefinitionNode.$(H) $(INCLUDE_TOP)\jv\cface\Cface__CNode.$(H) $(INCLUDE_TOP)\jv\cface\Cface__CTypeNode.$(H) $(INCLUDE_TOP)\stx\libbasic\Object.$(H) $(STCHDR)
+$(OUTDIR)Cface__CStructuredNode.$(O) Cface__CStructuredNode.$(H): Cface__CStructuredNode.st $(INCLUDE_TOP)\jv\cface\Cface__CDefinitionNode.$(H) $(INCLUDE_TOP)\jv\cface\Cface__CDerivedTypeNode.$(H) $(INCLUDE_TOP)\jv\cface\Cface__CNode.$(H) $(INCLUDE_TOP)\jv\cface\Cface__CTypeNode.$(H) $(INCLUDE_TOP)\stx\libbasic\Object.$(H) $(STCHDR)
+$(OUTDIR)Cface__CVoidNode.$(O) Cface__CVoidNode.$(H): Cface__CVoidNode.st $(INCLUDE_TOP)\jv\cface\Cface__CBuiltinNode.$(H) $(INCLUDE_TOP)\jv\cface\Cface__CDefinitionNode.$(H) $(INCLUDE_TOP)\jv\cface\Cface__CNode.$(H) $(INCLUDE_TOP)\jv\cface\Cface__CTypeNode.$(H) $(INCLUDE_TOP)\stx\libbasic\Object.$(H) $(STCHDR)
+$(OUTDIR)Cface__CWCharNode.$(O) Cface__CWCharNode.$(H): Cface__CWCharNode.st $(INCLUDE_TOP)\jv\cface\Cface__CBuiltinNode.$(H) $(INCLUDE_TOP)\jv\cface\Cface__CDefinitionNode.$(H) $(INCLUDE_TOP)\jv\cface\Cface__CNode.$(H) $(INCLUDE_TOP)\jv\cface\Cface__CTypeNode.$(H) $(INCLUDE_TOP)\stx\libbasic\Object.$(H) $(STCHDR)
+$(OUTDIR)Cface__CStructNode.$(O) Cface__CStructNode.$(H): Cface__CStructNode.st $(INCLUDE_TOP)\jv\cface\Cface__CDefinitionNode.$(H) $(INCLUDE_TOP)\jv\cface\Cface__CDerivedTypeNode.$(H) $(INCLUDE_TOP)\jv\cface\Cface__CNode.$(H) $(INCLUDE_TOP)\jv\cface\Cface__CStructuredNode.$(H) $(INCLUDE_TOP)\jv\cface\Cface__CTypeNode.$(H) $(INCLUDE_TOP)\stx\libbasic\Object.$(H) $(STCHDR)
+$(OUTDIR)Cface__CUnionNode.$(O) Cface__CUnionNode.$(H): Cface__CUnionNode.st $(INCLUDE_TOP)\jv\cface\Cface__CDefinitionNode.$(H) $(INCLUDE_TOP)\jv\cface\Cface__CDerivedTypeNode.$(H) $(INCLUDE_TOP)\jv\cface\Cface__CNode.$(H) $(INCLUDE_TOP)\jv\cface\Cface__CStructuredNode.$(H) $(INCLUDE_TOP)\jv\cface\Cface__CTypeNode.$(H) $(INCLUDE_TOP)\stx\libbasic\Object.$(H) $(STCHDR)
+$(OUTDIR)extensions.$(O): extensions.st $(INCLUDE_TOP)\stx\libbasic\Object.$(H) $(INCLUDE_TOP)\stx\libbasic\Stream.$(H) $(INCLUDE_TOP)\stx\libbasic3\Change.$(H) $(INCLUDE_TOP)\stx\libbasic3\ClassChange.$(H) $(INCLUDE_TOP)\stx\libbasic3\ClassDefinitionChange.$(H) $(STCHDR)
 
 # ENDMAKEDEPEND --- do not remove this line
+
+# **Must be at end**
+
+# Enforce recompilation of package definition class if Mercurial working
+# copy state changes. Together with --guessVersion it ensures that package
+# definition class always contains correct binary revision string.
+!IFDEF HGROOT
+$(OUTDIR)jv_cface.$(O): $(HGROOT)\.hg\dirstate
+!ENDIF
--- a/bmake.bat	Tue Sep 23 16:52:40 2014 +0100
+++ b/bmake.bat	Fri Dec 26 23:53:37 2014 +0100
@@ -3,6 +3,10 @@
 @REM type bmake, and wait...
 @REM do not edit - automatically generated from ProjectDefinition
 @REM -------
-make.exe -N -f bc.mak %*
+@SET DEFINES=
+@REM Kludge got Mercurial, cannot be implemented in Borland make
+@FOR /F "tokens=*" %%i in ('hg root') do SET HGROOT=%%i
+@IF "%HGROOT%" NEQ "" SET DEFINES=%DEFINES% "-DHGROOT=%HGROOT%"
+make.exe -N -f bc.mak  %DEFINES% %*
 
 
--- a/cface.rc	Tue Sep 23 16:52:40 2014 +0100
+++ b/cface.rc	Fri Dec 26 23:53:37 2014 +0100
@@ -3,8 +3,8 @@
 // automagically generated from the projectDefinition: jv_cface.
 //
 VS_VERSION_INFO VERSIONINFO
-  FILEVERSION     6,2,25,25
-  PRODUCTVERSION  6,2,3,1
+  FILEVERSION     6,2,32767,32767
+  PRODUCTVERSION  6,2,5,0
 #if (__BORLANDC__)
   FILEFLAGSMASK   VS_FF_DEBUG | VS_FF_PRERELEASE
   FILEFLAGS       VS_FF_PRERELEASE | VS_FF_SPECIALBUILD
@@ -20,12 +20,12 @@
     BEGIN
       VALUE "CompanyName", "CVUT FEL\0"
       VALUE "FileDescription", "Cairo graphics binding (LIB)\0"
-      VALUE "FileVersion", "6.2.25.25\0"
+      VALUE "FileVersion", "6.2.32767.32767\0"
       VALUE "InternalName", "jv:cface\0"
       VALUE "LegalCopyright", "Copyright 2008 Jan Vrany\0"
       VALUE "ProductName", "CairoGraphics\0"
-      VALUE "ProductVersion", "6.2.3.1\0"
-      VALUE "ProductDate", "Mon, 17 Sep 2012 20:25:26 GMT\0"
+      VALUE "ProductVersion", "6.2.5.0\0"
+      VALUE "ProductDate", "Fri, 26 Dec 2014 22:53:12 GMT\0"
     END
 
   END
--- a/extensions.st	Tue Sep 23 16:52:40 2014 +0100
+++ b/extensions.st	Fri Dec 26 23:53:37 2014 +0100
@@ -20,6 +20,7 @@
 
 !jv_cface class methodsFor:'documentation'!
 
-extensionsVersion_SVN
-    ^ '$Id::                                                                                                                        $'
+extensionsVersion_HG
+
+    ^ '$Changeset: <not expanded> $'
 ! !
--- a/jv_cface.st	Tue Sep 23 16:52:40 2014 +0100
+++ b/jv_cface.st	Fri Dec 26 23:53:37 2014 +0100
@@ -153,6 +153,11 @@
     ^'$Id$'
 !
 
+version_HG
+    ^ '$Changeset: <not expanded> $'
+!
+
 version_SVN
     ^ '$Id$'
 ! !
+
--- a/lccmake.bat	Tue Sep 23 16:52:40 2014 +0100
+++ b/lccmake.bat	Fri Dec 26 23:53:37 2014 +0100
@@ -3,6 +3,6 @@
 @REM type lccmake, and wait...
 @REM do not edit - automatically generated from ProjectDefinition
 @REM -------
-make.exe -N -f bc.mak USELCC=1 %*
+make.exe -N -f bc.mak -DUSELCC=1 %*
 
 
--- a/libInit.cc	Tue Sep 23 16:52:40 2014 +0100
+++ b/libInit.cc	Fri Dec 26 23:53:37 2014 +0100
@@ -13,16 +13,16 @@
 
 #if defined(INIT_TEXT_SECTION) || defined(DLL_EXPORT)
 DLL_EXPORT void _libjv_cface_Init() INIT_TEXT_SECTION;
-// DLL_EXPORT void _libjv_cface_InitDefinition() INIT_TEXT_SECTION;
+DLL_EXPORT void _libjv_cface_InitDefinition() INIT_TEXT_SECTION;
 #endif
 
-// void _libjv_cface_InitDefinition(pass, __pRT__, snd)
-// OBJ snd; struct __vmData__ *__pRT__; {
-// __BEGIN_PACKAGE2__("libjv_cface__DFN", _libjv_cface_InitDefinition, "jv:cface");
-// _jv_137cface_Init(pass,__pRT__,snd);
+void _libjv_cface_InitDefinition(pass, __pRT__, snd)
+OBJ snd; struct __vmData__ *__pRT__; {
+__BEGIN_PACKAGE2__("libjv_cface__DFN", _libjv_cface_InitDefinition, "jv:cface");
+_jv_137cface_Init(pass,__pRT__,snd);
 
-// __END_PACKAGE__();
-// }
+__END_PACKAGE__();
+}
 
 void _libjv_cface_Init(pass, __pRT__, snd)
 OBJ snd; struct __vmData__ *__pRT__; {
--- a/mingwmake.bat	Tue Sep 23 16:52:40 2014 +0100
+++ b/mingwmake.bat	Fri Dec 26 23:53:37 2014 +0100
@@ -3,6 +3,14 @@
 @REM type mingwmake, and wait...
 @REM do not edit - automatically generated from ProjectDefinition
 @REM -------
-make.exe -N -f bc.mak USEMINGW=1 %*
+@SET DEFINES=
+@REM Kludge got Mercurial, cannot be implemented in Borland make
+@FOR /F "tokens=*" %%i in ('hg root') do SET HGROOT=%%i
+@IF "%HGROOT%" NEQ "" SET DEFINES=%DEFINES% "-DHGROOT=%HGROOT%"
+
+@pushd ..\..\stx\rules
+@call find_mingw.bat
+@popd
+make.exe -N -f bc.mak %DEFINES% %USEMINGW_ARG% %*
 
 
--- a/vcmake.bat	Tue Sep 23 16:52:40 2014 +0100
+++ b/vcmake.bat	Fri Dec 26 23:53:37 2014 +0100
@@ -5,8 +5,16 @@
 @REM -------
 
 @if not defined VSINSTALLDIR (
-    call ..\..\..\stx\rules\vcsetup.bat
+    pushd ..\..\stx\rules
+    call vcsetup.bat
+    popd
 )
-make.exe -N -f bc.mak -DUSEVC %*
+@SET DEFINES=
+@REM Kludge got Mercurial, cannot be implemented in Borland make
+@FOR /F "tokens=*" %%i in ('hg root') do SET HGROOT=%%i
+@IF "%HGROOT%" NEQ "" SET DEFINES=%DEFINES% "-DHGROOT=%HGROOT%"
+make.exe -N -f bc.mak -DUSEVC=1 %DEFINES% %*
 
 
+
+
--- a/Make.proto	Tue Sep 23 16:52:40 2014 +0100
+++ b/Make.proto	Fri Dec 26 23:53:37 2014 +0100
@@ -68,7 +68,7 @@
 
 
 
 # Update SVN revision in stx_libbasic3.st
 ifneq (,$(findstring .svn,$(wildcard .svn)))
 .svnversion: *.st
 	if [ -d .svn ]; then \
@@ -78,7 +78,7 @@
 		echo -n exported > .svnversion; \
 	fi
 
-jv_cface.o: jv_cface.st .svnversion 
+jv_cface.o: jv_cface.st .svnversion
 	@if [ -d .svn ]; then \
 		rev2="$(shell printf "%-16s" $$(cat .svnversion))"; \
 		echo "  [SV]  Expanding svnRevisionNo in $1.st"; \
@@ -87,11 +87,27 @@
 	$(MAKE) CC="$(CLASSLIB_CC)" OPT="$(OPT)" SEPINITCODE="$(SEPINITCODE)" STC="$(STC)" STFILE=.jv_cface.svn $(C_RULE);
 	sed -i -e "s/\".jv_cface.svn.st\");/\"\jv_cface.st\");/g" .jv_cface.svn.c
 	$(MAKE) .jv_cface.svn.$(O)
-	@mv .jv_cface.svn.$(O) jv_cface.$(O) 
+	@mv .jv_cface.svn.$(O) jv_cface.$(O)
 endif
 
 
 
+# Enforce recompilation of package definition class if Mercurial working
+# copy state changes. Together with --guessVersion it ensures that package
+# definition class always contains correct binary revision string.
+ifneq (**NOHG**, $(shell hg root 2> /dev/null || echo -n '**NOHG**'))
+jv_cface.$(O): $(shell hg root)/.hg/dirstate
+endif
+
+
+
+
+# run default testsuite for this package
+test: $(TOP)/goodies/builder/reports
+	$(MAKE) -C $(TOP)/goodies/builder/reports -f Makefile.init
+	$(TOP)/goodies/builder/reports/report-runner.sh -D . -r Builder::TestReport -p $(PACKAGE)
+
+
 
 # add more install actions here
 install::
@@ -105,27 +121,20 @@
 # add more postMake actions here
 postMake:: cleanjunk
 
-prereq: $(REQUIRED_SUPPORT_DIRS)
+# build all mandatory prerequisite packages (containing superclasses) for this package
+prereq:
 	cd $(TOP)/libbasic && $(MAKE) "CFLAGS_LOCAL=$(GLOBALDEFINES)"
-	cd $(TOP)/goodies/refactoryBrowser/helpers && $(MAKE) "CFLAGS_LOCAL=$(GLOBALDEFINES)"
-	cd $(TOP)/goodies/refactoryBrowser/parser && $(MAKE) "CFLAGS_LOCAL=$(GLOBALDEFINES)"
 	cd $(TOP)/libbasic2 && $(MAKE) "CFLAGS_LOCAL=$(GLOBALDEFINES)"
-	cd $(TOP)/libcomp && $(MAKE) "CFLAGS_LOCAL=$(GLOBALDEFINES)"
+	cd $(TOP)/libbasic3 && $(MAKE) "CFLAGS_LOCAL=$(GLOBALDEFINES)"
 	cd $(TOP)/libview && $(MAKE) "CFLAGS_LOCAL=$(GLOBALDEFINES)"
-	cd $(TOP)/libdb && $(MAKE) "CFLAGS_LOCAL=$(GLOBALDEFINES)"
 	cd $(TOP)/libview2 && $(MAKE) "CFLAGS_LOCAL=$(GLOBALDEFINES)"
-	cd $(TOP)/libdb/libodbc && $(MAKE) "CFLAGS_LOCAL=$(GLOBALDEFINES)"
-	cd $(TOP)/libdb/libsqlite && $(MAKE) "CFLAGS_LOCAL=$(GLOBALDEFINES)"
-	cd $(TOP)/goodies/sunit && $(MAKE) "CFLAGS_LOCAL=$(GLOBALDEFINES)"
-	cd $(TOP)/libui && $(MAKE) "CFLAGS_LOCAL=$(GLOBALDEFINES)"
-	cd $(TOP)/libbasic3 && $(MAKE) "CFLAGS_LOCAL=$(GLOBALDEFINES)"
-	cd $(TOP)/libwidg && $(MAKE) "CFLAGS_LOCAL=$(GLOBALDEFINES)"
-	cd $(TOP)/goodies/refactoryBrowser/changes && $(MAKE) "CFLAGS_LOCAL=$(GLOBALDEFINES)"
-	cd $(TOP)/libhtml && $(MAKE) "CFLAGS_LOCAL=$(GLOBALDEFINES)"
-	cd $(TOP)/libwidg2 && $(MAKE) "CFLAGS_LOCAL=$(GLOBALDEFINES)"
 	cd $(TOP)/goodies/smaCC && $(MAKE) "CFLAGS_LOCAL=$(GLOBALDEFINES)"
-	cd $(TOP)/librun && $(MAKE) "CFLAGS_LOCAL=$(GLOBALDEFINES)"
+
+
 
+# build all packages containing referenced classes for this package
+# they are not needed to compile the package (but later, to load it)
+references:
 
 
 cleanjunk::
@@ -146,7 +155,7 @@
 $(OUTDIR)Cface__GeneratorCommand.$(O) Cface__GeneratorCommand.$(H): Cface__GeneratorCommand.st $(INCLUDE_TOP)/stx/libbasic/Object.$(H) $(STCHDR)
 $(OUTDIR)Cface__Platform.$(O) Cface__Platform.$(H): Cface__Platform.st $(INCLUDE_TOP)/stx/libbasic/Object.$(H) $(STCHDR)
 $(OUTDIR)Cface__TypeMapping.$(O) Cface__TypeMapping.$(H): Cface__TypeMapping.st $(INCLUDE_TOP)/stx/libbasic/Object.$(H) $(STCHDR)
-$(OUTDIR)jv_cface.$(O) jv_cface.$(H): jv_cface.st $(INCLUDE_TOP)/stx/libbasic/LibraryDefinition.$(H) $(INCLUDE_TOP)/stx/libbasic/ProjectDefinition.$(H) $(INCLUDE_TOP)/stx/libbasic/Object.$(H) $(STCHDR)
+$(OUTDIR)jv_cface.$(O) jv_cface.$(H): jv_cface.st $(INCLUDE_TOP)/stx/libbasic/LibraryDefinition.$(H) $(INCLUDE_TOP)/stx/libbasic/Object.$(H) $(INCLUDE_TOP)/stx/libbasic/ProjectDefinition.$(H) $(STCHDR)
 $(OUTDIR)Cface__CDefinitionNode.$(O) Cface__CDefinitionNode.$(H): Cface__CDefinitionNode.st $(INCLUDE_TOP)/jv/cface/Cface__CNode.$(H) $(INCLUDE_TOP)/stx/libbasic/Object.$(H) $(STCHDR)
 $(OUTDIR)Cface__CModifierNode.$(O) Cface__CModifierNode.$(H): Cface__CModifierNode.st $(INCLUDE_TOP)/jv/cface/Cface__CNode.$(H) $(INCLUDE_TOP)/stx/libbasic/Object.$(H) $(STCHDR)
 $(OUTDIR)Cface__CNoNode.$(O) Cface__CNoNode.$(H): Cface__CNoNode.st $(INCLUDE_TOP)/jv/cface/Cface__CNode.$(H) $(INCLUDE_TOP)/stx/libbasic/Object.$(H) $(STCHDR)
@@ -169,25 +178,25 @@
 $(OUTDIR)Cface__CStructFieldNode.$(O) Cface__CStructFieldNode.$(H): Cface__CStructFieldNode.st $(INCLUDE_TOP)/jv/cface/Cface__CDefinitionNode.$(H) $(INCLUDE_TOP)/jv/cface/Cface__CNode.$(H) $(INCLUDE_TOP)/stx/libbasic/Object.$(H) $(STCHDR)
 $(OUTDIR)Cface__CTypeNode.$(O) Cface__CTypeNode.$(H): Cface__CTypeNode.st $(INCLUDE_TOP)/jv/cface/Cface__CDefinitionNode.$(H) $(INCLUDE_TOP)/jv/cface/Cface__CNode.$(H) $(INCLUDE_TOP)/stx/libbasic/Object.$(H) $(STCHDR)
 $(OUTDIR)Cface__CUnsignedNode.$(O) Cface__CUnsignedNode.$(H): Cface__CUnsignedNode.st $(INCLUDE_TOP)/jv/cface/Cface__CModifierNode.$(H) $(INCLUDE_TOP)/jv/cface/Cface__CNode.$(H) $(INCLUDE_TOP)/stx/libbasic/Object.$(H) $(STCHDR)
-$(OUTDIR)Cface__SmalltalkXGenerator.$(O) Cface__SmalltalkXGenerator.$(H): Cface__SmalltalkXGenerator.st $(INCLUDE_TOP)/jv/cface/Cface__Generator.$(H) $(INCLUDE_TOP)/jv/cface/Cface__CNodeVisitor.$(H) $(INCLUDE_TOP)/stx/libbasic/Object.$(H) $(STCHDR)
-$(OUTDIR)Cface__CArrayNode.$(O) Cface__CArrayNode.$(H): Cface__CArrayNode.st $(INCLUDE_TOP)/jv/cface/Cface__CTypeNode.$(H) $(INCLUDE_TOP)/jv/cface/Cface__CDefinitionNode.$(H) $(INCLUDE_TOP)/jv/cface/Cface__CNode.$(H) $(INCLUDE_TOP)/stx/libbasic/Object.$(H) $(STCHDR)
-$(OUTDIR)Cface__CBuiltinNode.$(O) Cface__CBuiltinNode.$(H): Cface__CBuiltinNode.st $(INCLUDE_TOP)/jv/cface/Cface__CTypeNode.$(H) $(INCLUDE_TOP)/jv/cface/Cface__CDefinitionNode.$(H) $(INCLUDE_TOP)/jv/cface/Cface__CNode.$(H) $(INCLUDE_TOP)/stx/libbasic/Object.$(H) $(STCHDR)
-$(OUTDIR)Cface__CDerivedTypeNode.$(O) Cface__CDerivedTypeNode.$(H): Cface__CDerivedTypeNode.st $(INCLUDE_TOP)/jv/cface/Cface__CTypeNode.$(H) $(INCLUDE_TOP)/jv/cface/Cface__CDefinitionNode.$(H) $(INCLUDE_TOP)/jv/cface/Cface__CNode.$(H) $(INCLUDE_TOP)/stx/libbasic/Object.$(H) $(STCHDR)
-$(OUTDIR)Cface__CPointerNode.$(O) Cface__CPointerNode.$(H): Cface__CPointerNode.st $(INCLUDE_TOP)/jv/cface/Cface__CTypeNode.$(H) $(INCLUDE_TOP)/jv/cface/Cface__CDefinitionNode.$(H) $(INCLUDE_TOP)/jv/cface/Cface__CNode.$(H) $(INCLUDE_TOP)/stx/libbasic/Object.$(H) $(STCHDR)
-$(OUTDIR)Cface__CTypedefNode.$(O) Cface__CTypedefNode.$(H): Cface__CTypedefNode.st $(INCLUDE_TOP)/jv/cface/Cface__CTypeNode.$(H) $(INCLUDE_TOP)/jv/cface/Cface__CDefinitionNode.$(H) $(INCLUDE_TOP)/jv/cface/Cface__CNode.$(H) $(INCLUDE_TOP)/stx/libbasic/Object.$(H) $(STCHDR)
-$(OUTDIR)Cface__CUserDefinedTypeNode.$(O) Cface__CUserDefinedTypeNode.$(H): Cface__CUserDefinedTypeNode.st $(INCLUDE_TOP)/jv/cface/Cface__CTypeNode.$(H) $(INCLUDE_TOP)/jv/cface/Cface__CDefinitionNode.$(H) $(INCLUDE_TOP)/jv/cface/Cface__CNode.$(H) $(INCLUDE_TOP)/stx/libbasic/Object.$(H) $(STCHDR)
-$(OUTDIR)Cface__CCharNode.$(O) Cface__CCharNode.$(H): Cface__CCharNode.st $(INCLUDE_TOP)/jv/cface/Cface__CBuiltinNode.$(H) $(INCLUDE_TOP)/jv/cface/Cface__CTypeNode.$(H) $(INCLUDE_TOP)/jv/cface/Cface__CDefinitionNode.$(H) $(INCLUDE_TOP)/jv/cface/Cface__CNode.$(H) $(INCLUDE_TOP)/stx/libbasic/Object.$(H) $(STCHDR)
-$(OUTDIR)Cface__CDoubleNode.$(O) Cface__CDoubleNode.$(H): Cface__CDoubleNode.st $(INCLUDE_TOP)/jv/cface/Cface__CBuiltinNode.$(H) $(INCLUDE_TOP)/jv/cface/Cface__CTypeNode.$(H) $(INCLUDE_TOP)/jv/cface/Cface__CDefinitionNode.$(H) $(INCLUDE_TOP)/jv/cface/Cface__CNode.$(H) $(INCLUDE_TOP)/stx/libbasic/Object.$(H) $(STCHDR)
-$(OUTDIR)Cface__CEnumNode.$(O) Cface__CEnumNode.$(H): Cface__CEnumNode.st $(INCLUDE_TOP)/jv/cface/Cface__CDerivedTypeNode.$(H) $(INCLUDE_TOP)/jv/cface/Cface__CTypeNode.$(H) $(INCLUDE_TOP)/jv/cface/Cface__CDefinitionNode.$(H) $(INCLUDE_TOP)/jv/cface/Cface__CNode.$(H) $(INCLUDE_TOP)/stx/libbasic/Object.$(H) $(STCHDR)
-$(OUTDIR)Cface__CFloatNode.$(O) Cface__CFloatNode.$(H): Cface__CFloatNode.st $(INCLUDE_TOP)/jv/cface/Cface__CBuiltinNode.$(H) $(INCLUDE_TOP)/jv/cface/Cface__CTypeNode.$(H) $(INCLUDE_TOP)/jv/cface/Cface__CDefinitionNode.$(H) $(INCLUDE_TOP)/jv/cface/Cface__CNode.$(H) $(INCLUDE_TOP)/stx/libbasic/Object.$(H) $(STCHDR)
-$(OUTDIR)Cface__CFunctionTypeNode.$(O) Cface__CFunctionTypeNode.$(H): Cface__CFunctionTypeNode.st $(INCLUDE_TOP)/jv/cface/Cface__CDerivedTypeNode.$(H) $(INCLUDE_TOP)/jv/cface/Cface__CTypeNode.$(H) $(INCLUDE_TOP)/jv/cface/Cface__CDefinitionNode.$(H) $(INCLUDE_TOP)/jv/cface/Cface__CNode.$(H) $(INCLUDE_TOP)/stx/libbasic/Object.$(H) $(STCHDR)
-$(OUTDIR)Cface__CIntNode.$(O) Cface__CIntNode.$(H): Cface__CIntNode.st $(INCLUDE_TOP)/jv/cface/Cface__CBuiltinNode.$(H) $(INCLUDE_TOP)/jv/cface/Cface__CTypeNode.$(H) $(INCLUDE_TOP)/jv/cface/Cface__CDefinitionNode.$(H) $(INCLUDE_TOP)/jv/cface/Cface__CNode.$(H) $(INCLUDE_TOP)/stx/libbasic/Object.$(H) $(STCHDR)
-$(OUTDIR)Cface__CStructuredNode.$(O) Cface__CStructuredNode.$(H): Cface__CStructuredNode.st $(INCLUDE_TOP)/jv/cface/Cface__CDerivedTypeNode.$(H) $(INCLUDE_TOP)/jv/cface/Cface__CTypeNode.$(H) $(INCLUDE_TOP)/jv/cface/Cface__CDefinitionNode.$(H) $(INCLUDE_TOP)/jv/cface/Cface__CNode.$(H) $(INCLUDE_TOP)/stx/libbasic/Object.$(H) $(STCHDR)
-$(OUTDIR)Cface__CVoidNode.$(O) Cface__CVoidNode.$(H): Cface__CVoidNode.st $(INCLUDE_TOP)/jv/cface/Cface__CBuiltinNode.$(H) $(INCLUDE_TOP)/jv/cface/Cface__CTypeNode.$(H) $(INCLUDE_TOP)/jv/cface/Cface__CDefinitionNode.$(H) $(INCLUDE_TOP)/jv/cface/Cface__CNode.$(H) $(INCLUDE_TOP)/stx/libbasic/Object.$(H) $(STCHDR)
-$(OUTDIR)Cface__CWCharNode.$(O) Cface__CWCharNode.$(H): Cface__CWCharNode.st $(INCLUDE_TOP)/jv/cface/Cface__CBuiltinNode.$(H) $(INCLUDE_TOP)/jv/cface/Cface__CTypeNode.$(H) $(INCLUDE_TOP)/jv/cface/Cface__CDefinitionNode.$(H) $(INCLUDE_TOP)/jv/cface/Cface__CNode.$(H) $(INCLUDE_TOP)/stx/libbasic/Object.$(H) $(STCHDR)
-$(OUTDIR)Cface__CStructNode.$(O) Cface__CStructNode.$(H): Cface__CStructNode.st $(INCLUDE_TOP)/jv/cface/Cface__CStructuredNode.$(H) $(INCLUDE_TOP)/jv/cface/Cface__CDerivedTypeNode.$(H) $(INCLUDE_TOP)/jv/cface/Cface__CTypeNode.$(H) $(INCLUDE_TOP)/jv/cface/Cface__CDefinitionNode.$(H) $(INCLUDE_TOP)/jv/cface/Cface__CNode.$(H) $(INCLUDE_TOP)/stx/libbasic/Object.$(H) $(STCHDR)
-$(OUTDIR)Cface__CUnionNode.$(O) Cface__CUnionNode.$(H): Cface__CUnionNode.st $(INCLUDE_TOP)/jv/cface/Cface__CStructuredNode.$(H) $(INCLUDE_TOP)/jv/cface/Cface__CDerivedTypeNode.$(H) $(INCLUDE_TOP)/jv/cface/Cface__CTypeNode.$(H) $(INCLUDE_TOP)/jv/cface/Cface__CDefinitionNode.$(H) $(INCLUDE_TOP)/jv/cface/Cface__CNode.$(H) $(INCLUDE_TOP)/stx/libbasic/Object.$(H) $(STCHDR)
-$(OUTDIR)extensions.$(O): extensions.st $(INCLUDE_TOP)/stx/libbasic3/ClassDefinitionChange.$(H) $(INCLUDE_TOP)/stx/libbasic3/ClassChange.$(H) $(INCLUDE_TOP)/stx/libbasic3/Change.$(H) $(INCLUDE_TOP)/stx/libbasic/Object.$(H) $(INCLUDE_TOP)/stx/libbasic/Stream.$(H) $(STCHDR)
+$(OUTDIR)Cface__SmalltalkXGenerator.$(O) Cface__SmalltalkXGenerator.$(H): Cface__SmalltalkXGenerator.st $(INCLUDE_TOP)/jv/cface/Cface__CNodeVisitor.$(H) $(INCLUDE_TOP)/jv/cface/Cface__Generator.$(H) $(INCLUDE_TOP)/stx/libbasic/Object.$(H) $(STCHDR)
+$(OUTDIR)Cface__CArrayNode.$(O) Cface__CArrayNode.$(H): Cface__CArrayNode.st $(INCLUDE_TOP)/jv/cface/Cface__CDefinitionNode.$(H) $(INCLUDE_TOP)/jv/cface/Cface__CNode.$(H) $(INCLUDE_TOP)/jv/cface/Cface__CTypeNode.$(H) $(INCLUDE_TOP)/stx/libbasic/Object.$(H) $(STCHDR)
+$(OUTDIR)Cface__CBuiltinNode.$(O) Cface__CBuiltinNode.$(H): Cface__CBuiltinNode.st $(INCLUDE_TOP)/jv/cface/Cface__CDefinitionNode.$(H) $(INCLUDE_TOP)/jv/cface/Cface__CNode.$(H) $(INCLUDE_TOP)/jv/cface/Cface__CTypeNode.$(H) $(INCLUDE_TOP)/stx/libbasic/Object.$(H) $(STCHDR)
+$(OUTDIR)Cface__CDerivedTypeNode.$(O) Cface__CDerivedTypeNode.$(H): Cface__CDerivedTypeNode.st $(INCLUDE_TOP)/jv/cface/Cface__CDefinitionNode.$(H) $(INCLUDE_TOP)/jv/cface/Cface__CNode.$(H) $(INCLUDE_TOP)/jv/cface/Cface__CTypeNode.$(H) $(INCLUDE_TOP)/stx/libbasic/Object.$(H) $(STCHDR)
+$(OUTDIR)Cface__CPointerNode.$(O) Cface__CPointerNode.$(H): Cface__CPointerNode.st $(INCLUDE_TOP)/jv/cface/Cface__CDefinitionNode.$(H) $(INCLUDE_TOP)/jv/cface/Cface__CNode.$(H) $(INCLUDE_TOP)/jv/cface/Cface__CTypeNode.$(H) $(INCLUDE_TOP)/stx/libbasic/Object.$(H) $(STCHDR)
+$(OUTDIR)Cface__CTypedefNode.$(O) Cface__CTypedefNode.$(H): Cface__CTypedefNode.st $(INCLUDE_TOP)/jv/cface/Cface__CDefinitionNode.$(H) $(INCLUDE_TOP)/jv/cface/Cface__CNode.$(H) $(INCLUDE_TOP)/jv/cface/Cface__CTypeNode.$(H) $(INCLUDE_TOP)/stx/libbasic/Object.$(H) $(STCHDR)
+$(OUTDIR)Cface__CUserDefinedTypeNode.$(O) Cface__CUserDefinedTypeNode.$(H): Cface__CUserDefinedTypeNode.st $(INCLUDE_TOP)/jv/cface/Cface__CDefinitionNode.$(H) $(INCLUDE_TOP)/jv/cface/Cface__CNode.$(H) $(INCLUDE_TOP)/jv/cface/Cface__CTypeNode.$(H) $(INCLUDE_TOP)/stx/libbasic/Object.$(H) $(STCHDR)
+$(OUTDIR)Cface__CCharNode.$(O) Cface__CCharNode.$(H): Cface__CCharNode.st $(INCLUDE_TOP)/jv/cface/Cface__CBuiltinNode.$(H) $(INCLUDE_TOP)/jv/cface/Cface__CDefinitionNode.$(H) $(INCLUDE_TOP)/jv/cface/Cface__CNode.$(H) $(INCLUDE_TOP)/jv/cface/Cface__CTypeNode.$(H) $(INCLUDE_TOP)/stx/libbasic/Object.$(H) $(STCHDR)
+$(OUTDIR)Cface__CDoubleNode.$(O) Cface__CDoubleNode.$(H): Cface__CDoubleNode.st $(INCLUDE_TOP)/jv/cface/Cface__CBuiltinNode.$(H) $(INCLUDE_TOP)/jv/cface/Cface__CDefinitionNode.$(H) $(INCLUDE_TOP)/jv/cface/Cface__CNode.$(H) $(INCLUDE_TOP)/jv/cface/Cface__CTypeNode.$(H) $(INCLUDE_TOP)/stx/libbasic/Object.$(H) $(STCHDR)
+$(OUTDIR)Cface__CEnumNode.$(O) Cface__CEnumNode.$(H): Cface__CEnumNode.st $(INCLUDE_TOP)/jv/cface/Cface__CDefinitionNode.$(H) $(INCLUDE_TOP)/jv/cface/Cface__CDerivedTypeNode.$(H) $(INCLUDE_TOP)/jv/cface/Cface__CNode.$(H) $(INCLUDE_TOP)/jv/cface/Cface__CTypeNode.$(H) $(INCLUDE_TOP)/stx/libbasic/Object.$(H) $(STCHDR)
+$(OUTDIR)Cface__CFloatNode.$(O) Cface__CFloatNode.$(H): Cface__CFloatNode.st $(INCLUDE_TOP)/jv/cface/Cface__CBuiltinNode.$(H) $(INCLUDE_TOP)/jv/cface/Cface__CDefinitionNode.$(H) $(INCLUDE_TOP)/jv/cface/Cface__CNode.$(H) $(INCLUDE_TOP)/jv/cface/Cface__CTypeNode.$(H) $(INCLUDE_TOP)/stx/libbasic/Object.$(H) $(STCHDR)
+$(OUTDIR)Cface__CFunctionTypeNode.$(O) Cface__CFunctionTypeNode.$(H): Cface__CFunctionTypeNode.st $(INCLUDE_TOP)/jv/cface/Cface__CDefinitionNode.$(H) $(INCLUDE_TOP)/jv/cface/Cface__CDerivedTypeNode.$(H) $(INCLUDE_TOP)/jv/cface/Cface__CNode.$(H) $(INCLUDE_TOP)/jv/cface/Cface__CTypeNode.$(H) $(INCLUDE_TOP)/stx/libbasic/Object.$(H) $(STCHDR)
+$(OUTDIR)Cface__CIntNode.$(O) Cface__CIntNode.$(H): Cface__CIntNode.st $(INCLUDE_TOP)/jv/cface/Cface__CBuiltinNode.$(H) $(INCLUDE_TOP)/jv/cface/Cface__CDefinitionNode.$(H) $(INCLUDE_TOP)/jv/cface/Cface__CNode.$(H) $(INCLUDE_TOP)/jv/cface/Cface__CTypeNode.$(H) $(INCLUDE_TOP)/stx/libbasic/Object.$(H) $(STCHDR)
+$(OUTDIR)Cface__CStructuredNode.$(O) Cface__CStructuredNode.$(H): Cface__CStructuredNode.st $(INCLUDE_TOP)/jv/cface/Cface__CDefinitionNode.$(H) $(INCLUDE_TOP)/jv/cface/Cface__CDerivedTypeNode.$(H) $(INCLUDE_TOP)/jv/cface/Cface__CNode.$(H) $(INCLUDE_TOP)/jv/cface/Cface__CTypeNode.$(H) $(INCLUDE_TOP)/stx/libbasic/Object.$(H) $(STCHDR)
+$(OUTDIR)Cface__CVoidNode.$(O) Cface__CVoidNode.$(H): Cface__CVoidNode.st $(INCLUDE_TOP)/jv/cface/Cface__CBuiltinNode.$(H) $(INCLUDE_TOP)/jv/cface/Cface__CDefinitionNode.$(H) $(INCLUDE_TOP)/jv/cface/Cface__CNode.$(H) $(INCLUDE_TOP)/jv/cface/Cface__CTypeNode.$(H) $(INCLUDE_TOP)/stx/libbasic/Object.$(H) $(STCHDR)
+$(OUTDIR)Cface__CWCharNode.$(O) Cface__CWCharNode.$(H): Cface__CWCharNode.st $(INCLUDE_TOP)/jv/cface/Cface__CBuiltinNode.$(H) $(INCLUDE_TOP)/jv/cface/Cface__CDefinitionNode.$(H) $(INCLUDE_TOP)/jv/cface/Cface__CNode.$(H) $(INCLUDE_TOP)/jv/cface/Cface__CTypeNode.$(H) $(INCLUDE_TOP)/stx/libbasic/Object.$(H) $(STCHDR)
+$(OUTDIR)Cface__CStructNode.$(O) Cface__CStructNode.$(H): Cface__CStructNode.st $(INCLUDE_TOP)/jv/cface/Cface__CDefinitionNode.$(H) $(INCLUDE_TOP)/jv/cface/Cface__CDerivedTypeNode.$(H) $(INCLUDE_TOP)/jv/cface/Cface__CNode.$(H) $(INCLUDE_TOP)/jv/cface/Cface__CStructuredNode.$(H) $(INCLUDE_TOP)/jv/cface/Cface__CTypeNode.$(H) $(INCLUDE_TOP)/stx/libbasic/Object.$(H) $(STCHDR)
+$(OUTDIR)Cface__CUnionNode.$(O) Cface__CUnionNode.$(H): Cface__CUnionNode.st $(INCLUDE_TOP)/jv/cface/Cface__CDefinitionNode.$(H) $(INCLUDE_TOP)/jv/cface/Cface__CDerivedTypeNode.$(H) $(INCLUDE_TOP)/jv/cface/Cface__CNode.$(H) $(INCLUDE_TOP)/jv/cface/Cface__CStructuredNode.$(H) $(INCLUDE_TOP)/jv/cface/Cface__CTypeNode.$(H) $(INCLUDE_TOP)/stx/libbasic/Object.$(H) $(STCHDR)
+$(OUTDIR)extensions.$(O): extensions.st $(INCLUDE_TOP)/stx/libbasic/Object.$(H) $(INCLUDE_TOP)/stx/libbasic/Stream.$(H) $(INCLUDE_TOP)/stx/libbasic3/Change.$(H) $(INCLUDE_TOP)/stx/libbasic3/ClassChange.$(H) $(INCLUDE_TOP)/stx/libbasic3/ClassDefinitionChange.$(H) $(STCHDR)
 
 # ENDMAKEDEPEND --- do not remove this line
 
@@ -68,7 +68,7 @@
 
 
-# Update SVN revision in stx_libbasic3.st
+# Update SVN revision in package definition class
 ifneq (,$(findstring .svn,$(wildcard .svn)))
 .svnversion: *.st